package com.tptj.demo.hg.extension.button.provider;

import com.fr.design.fun.ExportToolBarProvider;
import com.fr.design.gui.icheckbox.UICheckBox;
import com.fr.general.ComparatorUtils;
import com.fr.report.fun.ExtensionButtonProvider;
import com.fr.stable.fun.impl.AbstractProvider;
import com.fr.stable.fun.mark.API;

import javax.swing.*;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

@API(level = ExportToolBarProvider.CURRENT_LEVEL)
public abstract class AbstractExportToolBarPane extends AbstractProvider implements ExportToolBarProvider {

    private static final int STRUT_LENGTH = 2;

    protected List<UICheckBox> boxes = new ArrayList<UICheckBox>();
    protected Set<ExtensionButtonProvider> providers = new HashSet<ExtensionButtonProvider>();

    public boolean equals(Object obj) {
        return obj instanceof AbstractExportToolBarPane &&
                ComparatorUtils.equals(boxes, ((AbstractExportToolBarPane) obj).boxes) &&
                ComparatorUtils.equals(providers, ((AbstractExportToolBarPane) obj).providers);
    }

    public int currentAPILevel() {
        return CURRENT_LEVEL;
    }

    @Override
    public String mark4Provider() {
        return getClass().getName();
    }

    /**
     * 根据设计器段checkbox是否被选中更新web端相应的按钮是否显示
     */
    public void populate() {
        updateOrPopulateRelatedValue(false);
    }

    /**
     * 根据web端(xml)里按钮是否显示的更新设计器端checkbox的状态
     */
    public void update() {
        updateOrPopulateRelatedValue(true);
    }

    /**
     * web端按钮和设计器端checkbox的相互关系
     *
     * @param isUpdateFromWeb 待说明
     */
    private void updateOrPopulateRelatedValue(boolean isUpdateFromWeb) {
        for (int i = 0; i < boxes.size(); i++) {
            UICheckBox box = boxes.get(i);
            for (ExtensionButtonProvider provider : providers) {
                if (!ComparatorUtils.equals(box.getText(), provider.getRelatedCheckBoxTitle())) {
                    continue;
                }

                if (isUpdateFromWeb) {
                    provider.setSelected(box.isSelected());
                    continue;
                }
                box.setSelected(provider.isSelected());
            }
        }
    }

    /**
     * 更新面板
     *
     * @param pane 面板
     * @return JPanel 面板
     */
    public JPanel updateCenterPane(JPanel pane) {
        for (int i = 0; i < boxes.size(); i++) {
            pane.add(boxes.get(i));
            pane.add(Box.createVerticalStrut(STRUT_LENGTH));
        }
        return pane;
    }

}